@@ -37,6 +37,7 @@ class TokenType(AutoName):
     LSHIFT = auto()
     RSHIFT = auto()
     LAMBDA = auto()
+    ANNOTATION = auto()
 
     SPACE = auto()
     BREAK = auto()
@@ -170,6 +171,7 @@ class TokenType(AutoName):
     UNION = auto()
     UNNEST = auto()
     UPDATE = auto()
+    USE = auto()
     VALUES = auto()
     VIEW = auto()
     WHEN = auto()
@@ -363,6 +365,7 @@ class Tokenizer:
         "UNION": TokenType.UNION,
         "UNNEST": TokenType.UNNEST,
         "UPDATE": TokenType.UPDATE,
+        "USE": TokenType.USE,
         "VALUES": TokenType.VALUES,
         "VIEW": TokenType.VIEW,
         "WHEN": TokenType.WHEN,
@@ -423,6 +426,7 @@ class Tokenizer:
         TokenType.SET,
         TokenType.SHOW,
         TokenType.TRUNCATE,
+        TokenType.USE,
     }
 
     ESCAPE_CODE = "__sqlglot_escape__"
@@ -518,9 +522,10 @@ class Tokenizer:
                 self._scan_string()
             elif self._char == self.identifier:
                 self._scan_identifier()
+            elif self._char == "#":
+                self._scan_annotation()
             else:
                 self._scan_var()
-
         return self.tokens
 
     def _chars(self, size):
@@ -596,6 +601,13 @@ class Tokenizer:
             return True
         return False
 
+    def _scan_annotation(self):
+        while (
+            not self._end and self._peek not in self.WHITE_SPACE and self._peek != ","
+        ):
+            self._advance()
+        self._add(TokenType.ANNOTATION, self._text[1:])
+
     def _scan_number(self):
         decimal = False
         scientific = 0
